Documentation
¶
Index ¶
- func CleanFSRoot(root string) string
- func DisplayPath(root string, name string) string
- func FindFSYAMLFiles(ctx context.Context, fsys fs.FS, root string) ([]string, error)
- func FindYAMLFiles(ctx context.Context, root string) ([]string, error)
- func IsYAMLFile(name string) bool
- func RelativePath(root string, filePath string) string
- func ResolveFSPath(root string, baseDir string, userPath string) (string, string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CleanFSRoot ¶
CleanFSRoot normalizes a root path for use with fs.FS while preserving nonblank leading and trailing whitespace.
func DisplayPath ¶
DisplayPath returns name relative to root for messages about fs.FS paths.
func FindFSYAMLFiles ¶
FindFSYAMLFiles returns root itself when it names a file. For a directory root, it returns sorted paths for .yaml and .yml files beneath that root.
func FindYAMLFiles ¶
FindYAMLFiles returns sorted full paths for .yaml and .yml files under root.
func IsYAMLFile ¶
func RelativePath ¶
RelativePath computes a clean relative path from root to path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.